# Contributors
The following individuals have contributed significantly to the CodeMeta crosswalk and specification, and should be cited as the authors of the specification. We welcome pull requests from people to add to this list if we missed anybody.

| Name             | Email                | Institution               | GitHub  |
|------------------|----------------------|-------------------------| --------|
| Matthew B. Jones | jones@nceas.ucsb.edu | NCEAS, UC Santa Barbara | [mbjones](http://github.com/mbjones) |
| Carl Boettiger   | | UC Berkeley | [cboettig](http://github.com/cboettig) |
| Abby Cabunoc Mayes | | Mozilla Science Lab | [acabunoc](http://github.com/acabunoc) |
| Arfon Smith | | GitHub | [arfon](http://github.com/arfon) |
| Peter Slaughter | slaughter@nceas.ucsb.edu | NCEAS, UC Santa Barbara | [gothub](http://github.com/gothub) |
| Kyle Niemeyer   | | | [kyleniemeyer](http://github.com/kyleniemeyer) |
| Yolanda Gil | | USC ISI | |
| Martin Fenner | | DataCite | |
| Krzysztof Nowak | | Zenodo | |
| Mark Hahnel | | figshare | |
| Luke Coy | | RIT & MSL | |
| Alice Allen | | ASCL | |
| Mercè Crosas | | Harvard IQSS | |
| Ashley Sands | | UCLA | |
| Neil Chue Hong | | SSI | |
| Patricia Cruse | | DataCite | |
| Dan Katz | | NCSA | |
| Carole Goble | | | |
| Ted Habermann | ted.habermann@gmail.com |  | [tedhabermann](https://github.com/tedhabermann) |
